==> vtwidget_1_0.tar.gz: vtwidget_1_0/bterm/topLevelShell1.h <==

/*******************************************************************************
       topLevelShell1.h
       This header file is included by topLevelShell1.c

*******************************************************************************/

#ifndef	_TOPLEVELSHELL1_INCLUDED
#define	_TOPLEVELSHELL1_INCLUDED


#include <stdio.h>
#include <Xm/Xm.h>
#include <Xm/MwmUtil.h>
#include <Xm/MenuShell.h>
#include "UxXt.h"

#include <Xm/CascadeB.h>
#include <Xm/PushB.h>
#include <Xm/RowColumn.h>
#include <Xm/Form.h>
#include <X11/Shell.h>

/*******************************************************************************
       The definition of the context structure:
       If you create multiple copies of your interface, the context
       structure ensures that your callbacks use the variables for the
       correct copy.

       For each swidget in the interface, each argument to the Interface
       function, and each variable in the Interface Specific section of the
       Declarations Editor, there is an entry in the context structure.
       and a #define.  The #define makes the variable name refer to the
       corresponding entry in the context structure.
*******************************************************************************/

typedef	struct
{
	Widget	UxtopLevelShell1;
	Widget	Uxform1;
	Widget	Uxmenu1;
	Widget	Uxmenu1_p2;
	Widget	Uxmenu1_p2_b1;
	Widget	Uxmenu1_top_b2;
	Widget	Uxmenu1_p1;
	Widget	Uxmenu1_p1_b1;
	Widget	Uxmenu1_top_b1;
	Widget	Uxmenu1_p8;
	Widget	Uxmenu1_p8_b1;
	Widget	Uxmenu1_p8_b2;
	Widget	Uxmenu1_top_b4;
	Widget	Uxmenu1_p3;
	Widget	Uxmenu1_p5;
	Widget	Uxmenu1_p5_b1;
	Widget	Uxmenu1_p5_b2;
	Widget	Uxmenu1_p5_b3;
	Widget	Uxmenu1_p5_b4;
	Widget	Uxmenu1_p5_b5;
	Widget	Uxmenu1_p5_b6;
	Widget	Uxmenu1_p3_b5;
	Widget	Uxmenu1_p6;
	Widget	Uxmenu1_p6_b1;
	Widget	Uxmenu1_p6_b2;
	Widget	Uxmenu1_p3_b6;
	Widget	Uxmenu1_p7;
	Widget	Uxmenu1_p7_b1;
	Widget	Uxmenu1_p7_b2;
	Widget	Uxmenu1_p3_b3;
	Widget	Uxmenu1_p3_b4;
	Widget	Uxmenu1_top_b3;
} _UxCtopLevelShell1;

#ifdef CONTEXT_MACRO_ACCESS
static _UxCtopLevelShell1      *UxTopLevelShell1Context;
#define topLevelShell1          UxTopLevelShell1Context->UxtopLevelShell1
#define form1                   UxTopLevelShell1Context->Uxform1
#define menu1                   UxTopLevelShell1Context->Uxmenu1
#define menu1_p2                UxTopLevelShell1Context->Uxmenu1_p2
#define menu1_p2_b1             UxTopLevelShell1Context->Uxmenu1_p2_b1
#define menu1_top_b2            UxTopLevelShell1Context->Uxmenu1_top_b2
#define menu1_p1                UxTopLevelShell1Context->Uxmenu1_p1
#define menu1_p1_b1             UxTopLevelShell1Context->Uxmenu1_p1_b1
#define menu1_top_b1            UxTopLevelShell1Context->Uxmenu1_top_b1
#define menu1_p8                UxTopLevelShell1Context->Uxmenu1_p8
#define menu1_p8_b1             UxTopLevelShell1Context->Uxmenu1_p8_b1
#define menu1_p8_b2             UxTopLevelShell1Context->Uxmenu1_p8_b2
#define menu1_top_b4            UxTopLevelShell1Context->Uxmenu1_top_b4
#define menu1_p3                UxTopLevelShell1Context->Uxmenu1_p3
#define menu1_p5                UxTopLevelShell1Context->Uxmenu1_p5
#define menu1_p5_b1             UxTopLevelShell1Context->Uxmenu1_p5_b1
#define menu1_p5_b2             UxTopLevelShell1Context->Uxmenu1_p5_b2
#define menu1_p5_b3             UxTopLevelShell1Context->Uxmenu1_p5_b3
#define menu1_p5_b4             UxTopLevelShell1Context->Uxmenu1_p5_b4
#define menu1_p5_b5             UxTopLevelShell1Context->Uxmenu1_p5_b5
#define menu1_p5_b6             UxTopLevelShell1Context->Uxmenu1_p5_b6
#define menu1_p3_b5             UxTopLevelShell1Context->Uxmenu1_p3_b5
#define menu1_p6                UxTopLevelShell1Context->Uxmenu1_p6
#define menu1_p6_b1             UxTopLevelShell1Context->Uxmenu1_p6_b1
#define menu1_p6_b2             UxTopLevelShell1Context->Uxmenu1_p6_b2
#define menu1_p3_b6             UxTopLevelShell1Context->Uxmenu1_p3_b6
#define menu1_p7                UxTopLevelShell1Context->Uxmenu1_p7
#define menu1_p7_b1             UxTopLevelShell1Context->Uxmenu1_p7_b1
#define menu1_p7_b2             UxTopLevelShell1Context->Uxmenu1_p7_b2
#define menu1_p3_b3             UxTopLevelShell1Context->Uxmenu1_p3_b3
#define menu1_p3_b4             UxTopLevelShell1Context->Uxmenu1_p3_b4
#define menu1_top_b3            UxTopLevelShell1Context->Uxmenu1_top_b3

#endif /* CONTEXT_MACRO_ACCESS */


/*******************************************************************************
       Declarations of global functions.
*******************************************************************************/

Widget	create_topLevelShell1();

#endif	/* _TOPLEVELSHELL1_INCLUDED */

==> vtwidget-1.3.tar.gz: vtwidget-1.3/bterm/topLevelShell1.h <==

/*******************************************************************************
       topLevelShell1.h
       This header file is included by topLevelShell1.c

*******************************************************************************/

#ifndef	_TOPLEVELSHELL1_INCLUDED
#define	_TOPLEVELSHELL1_INCLUDED

#include <stdio.h>

#ifdef MOTIF
#include <Xm/Xm.h>
#include <Xm/MwmUtil.h>
#include <Xm/MenuShell.h>
#endif /* MOTIF */

#include "UxXt.h"

#ifndef XKLOADDS
#define XKLOADDS
#endif /* XKLOADDS */

/*******************************************************************************
       The definition of the context structure:
       If you create multiple copies of your interface, the context
       structure ensures that your callbacks use the variables for the
       correct copy.

       For each swidget in the interface, each argument to the Interface
       function, and each variable in the Interface Specific section of the
       Declarations Editor, there is an entry in the context structure
       and a #define.  The #define makes the variable name refer to the
       corresponding entry in the context structure.
*******************************************************************************/

typedef	struct
{
	Widget	UxtopLevelShell1;
	Widget	Uxform1;
	Widget	Uxmenu1;
	Widget	Uxmenu1_p2;
	Widget	Uxmenu1_p2_b1;
	Widget	Uxmenu1_top_b2;
	Widget	Uxmenu1_p1;
	Widget	Uxmenu1_p1_b1;
	Widget	Uxmenu1_top_b1;
	Widget	Uxmenu1_p8;
	Widget	Uxmenu1_p8_b1;
	Widget	Uxmenu1_p8_b2;
	Widget	Uxmenu1_top_b4;
	Widget	Uxmenu1_p3;
	Widget	Uxmenu1_p5;
	Widget	Uxmenu1_p5_b1;
	Widget	Uxmenu1_p5_b2;
	Widget	Uxmenu1_p5_b3;
	Widget	Uxmenu1_p5_b4;
	Widget	Uxmenu1_p5_b5;
	Widget	Uxmenu1_p5_b6;
	Widget	Uxmenu1_p3_b5;
	Widget	Uxmenu1_p6;
	Widget	Uxmenu1_p6_b1;
	Widget	Uxmenu1_p6_b2;
	Widget	Uxmenu1_p3_b6;
	Widget	Uxmenu1_p7;
	Widget	Uxmenu1_p7_b1;
	Widget	Uxmenu1_p7_b2;
	Widget	Uxmenu1_p3_b3;
	Widget	Uxmenu1_p3_b4;
	Widget	Uxmenu1_top_b3;
} _UxCtopLevelShell1;

#ifdef CONTEXT_MACRO_ACCESS
static _UxCtopLevelShell1      *UxTopLevelShell1Context;
#define topLevelShell1          UxTopLevelShell1Context->UxtopLevelShell1
#define form1                   UxTopLevelShell1Context->Uxform1
#define menu1                   UxTopLevelShell1Context->Uxmenu1
#define menu1_p2                UxTopLevelShell1Context->Uxmenu1_p2
#define menu1_p2_b1             UxTopLevelShell1Context->Uxmenu1_p2_b1
#define menu1_top_b2            UxTopLevelShell1Context->Uxmenu1_top_b2
#define menu1_p1                UxTopLevelShell1Context->Uxmenu1_p1
#define menu1_p1_b1             UxTopLevelShell1Context->Uxmenu1_p1_b1
#define menu1_top_b1            UxTopLevelShell1Context->Uxmenu1_top_b1
#define menu1_p8                UxTopLevelShell1Context->Uxmenu1_p8
#define menu1_p8_b1             UxTopLevelShell1Context->Uxmenu1_p8_b1
#define menu1_p8_b2             UxTopLevelShell1Context->Uxmenu1_p8_b2
#define menu1_top_b4            UxTopLevelShell1Context->Uxmenu1_top_b4
#define menu1_p3                UxTopLevelShell1Context->Uxmenu1_p3
#define menu1_p5                UxTopLevelShell1Context->Uxmenu1_p5
#define menu1_p5_b1             UxTopLevelShell1Context->Uxmenu1_p5_b1
#define menu1_p5_b2             UxTopLevelShell1Context->Uxmenu1_p5_b2
#define menu1_p5_b3             UxTopLevelShell1Context->Uxmenu1_p5_b3
#define menu1_p5_b4             UxTopLevelShell1Context->Uxmenu1_p5_b4
#define menu1_p5_b5             UxTopLevelShell1Context->Uxmenu1_p5_b5
#define menu1_p5_b6             UxTopLevelShell1Context->Uxmenu1_p5_b6
#define menu1_p3_b5             UxTopLevelShell1Context->Uxmenu1_p3_b5
#define menu1_p6                UxTopLevelShell1Context->Uxmenu1_p6
#define menu1_p6_b1             UxTopLevelShell1Context->Uxmenu1_p6_b1
#define menu1_p6_b2             UxTopLevelShell1Context->Uxmenu1_p6_b2
#define menu1_p3_b6             UxTopLevelShell1Context->Uxmenu1_p3_b6
#define menu1_p7                UxTopLevelShell1Context->Uxmenu1_p7
#define menu1_p7_b1             UxTopLevelShell1Context->Uxmenu1_p7_b1
#define menu1_p7_b2             UxTopLevelShell1Context->Uxmenu1_p7_b2
#define menu1_p3_b3             UxTopLevelShell1Context->Uxmenu1_p3_b3
#define menu1_p3_b4             UxTopLevelShell1Context->Uxmenu1_p3_b4
#define menu1_top_b3            UxTopLevelShell1Context->Uxmenu1_top_b3

#endif /* CONTEXT_MACRO_ACCESS */


/*******************************************************************************
       Declarations of global functions.
*******************************************************************************/

Widget	create_topLevelShell1( void );

#endif	/* _TOPLEVELSHELL1_INCLUDED */
